# wbutil-py

`wbutil` utility library for the Python language.


## Requirements

Requires Python >= 3.5 (`typing` module). `wbutil` has no external dependencies.


## Installation

`wbutil` is available for download from PyPI:

    $ pip install wbutil

I keep the PyPI releases pretty well synced up with this repository, but if you
really need the most bleeding edge stuff, `pip` supports downloading via git:

    $ pip install git+https://github.com/wbadart/wbutil-py.git


## Contributing

If you have some nice utilities you'd like to see added, or tweaks you'd like to
see, [pull requests] are welcome. I'd be especially excited for someone to
undertake Python 2 compatibility, or to write some tests ;)


## License

MIT License. Please see [LICENSE] and [opensource.org] for more details.


[pull requests]: https://github.com/wbadart/wbutil-py/pulls
[LICENSE]: ./LICENSE
[opensource.org]: https://opensource.org/licenses/MIT
